# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "atellica800_cyto_astm"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&||||||||||P|LIS2-A2|20130715141912
    P|1||||NYME ANO
    O|1|123456||^^^1:10|R|20130603110342|||||N||||Serum||||||||||Q
    O|2|123456||^^^1|R|20130603110342|||||N||||Serum||||||||||Q
    O|3|123456||^^^1|R|20130603110342|||||C||||Serum||||||||||Q
    L|1|F
    """
    assert message == expected


def test_decode_query(self):
    worklist = self.decode(
        """
    H|\\^&|||Atellica UAS 800^Atellica UAS 800^4.0.123.6420^1^H100017|||||||P|LIS2-A2|20180628104335
    Q|1|^0416||||||||||O
    L|1|N
    """
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "0416"}],
    }
    assert worklist == expected


def test_decode_result(self):
    self.configure(
        atellica_cyto_ignorer_resultats_na=False,
        atellica_cyto_exclusion_resultat_cristaux="",
        atellica_cyto_exclusion_resultat_cylindres="",
    )
    date = datetime.datetime(2017, 10, 27, 9, 10, 30)
    worklist = self.decode(
        """
    H|\\^&|||Atellica UAS 800^Atellica UAS 800^4.0.90.5575^1^H100016|||||||P|LIS2-A2|20171027094601
    P|1||||Name in user sw
    C|1|I|Sediment comment in user sw|G
    C|2|I|Review|I
    C|3|I|Low Level|I
    C|4|I|Dilution factor2.5|I
    O|1|0064|1^5^opera^SAMPLE|S|R||||||N|||20171027091030|||||||||||F
    R|1|798-9^^^RBC|132|p/ul||A||F||test|||Atellica UAS 800
    C|1|I|A|I
    R|2|51487-7^^^WBC|267.3|p/ul||A||F||test|||Atellica UAS 800
    C|1|I|A|I
    R|3|33768-3^^^.WBCc|-|||N||F||test|||Atellica UAS 800
    R|4|53334-9^^^CRY|+++|||A||F||test|||Atellica UAS 800
    R|5|53334-9^^^CRY|0.44|p/ul||N||F||test|||Atellica UAS 800
    C|1|I|A|I
    R|6|53334-9^^^.CaOxm|N/A|||A||F||test|||Atellica UAS 800
    R|7|53334-9^^^.CaOxm|0.55|p/ul||N||F||test|||Atellica UAS 800
    C|1|I|A|I
    R|8|50231-0^^^HYA|++++|||A||F||test|||Atellica UAS 800
    C|1|I|A|I
    R|9|72224-9^^^PAT|+|||A||F||test|||Atellica UAS 800
    C|1|I|A|I
    R|10|50225-2^^^NEC|-|||N||F||test|||Atellica UAS 800
    R|11|53318-2^^^EPI|++++|||A||F||test|||Atellica UAS 800
    C|1|I|A|I
    R|12|72223-1^^^YEA|-|||N||F||test|||Atellica UAS 800
    R|13|50221-1^^^BAC|++|||A||F||test|||Atellica UAS 800
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "0064",
                "rack": "1-5",
                "results": [
                    {
                        "code": "RBC",
                        "date": date,
                        "flags": ["A"],
                        "instrument": "H100016",
                        "operator": "test",
                        "unit": "p/ul",
                        "value": "132",
                    },
                    {
                        "code": "WBC",
                        "date": date,
                        "flags": ["A"],
                        "instrument": "H100016",
                        "operator": "test",
                        "unit": "p/ul",
                        "value": "267.3",
                    },
                    {
                        "code": ".WBCcQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100016",
                        "operator": "test",
                        "unit": "",
                        "value": "-",
                    },
                    {
                        "code": "CRY",
                        "date": date,
                        "flags": [],
                        "instrument": "H100016",
                        "operator": "test",
                        "unit": "p/ul",
                        "value": "0.44",
                    },
                    {
                        "code": ".CaOxm",
                        "date": date,
                        "flags": [],
                        "instrument": "H100016",
                        "operator": "test",
                        "unit": "p/ul",
                        "value": "0.55",
                    },
                    {
                        "code": "NECQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100016",
                        "operator": "test",
                        "unit": "",
                        "value": "-",
                    },
                    {
                        "code": "EPIQUAL",
                        "date": date,
                        "flags": ["A"],
                        "instrument": "H100016",
                        "operator": "test",
                        "unit": "",
                        "value": "++++",
                    },
                    {
                        "code": "YEAQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100016",
                        "operator": "test",
                        "unit": "",
                        "value": "-",
                    },
                    {
                        "code": "BACQUAL",
                        "date": date,
                        "flags": ["A"],
                        "instrument": "H100016",
                        "operator": "test",
                        "unit": "",
                        "value": "++",
                    },
                    {
                        "code": "CRISTAUX",
                        "value": "CRY+++;.CaOxmN/A",
                        "instrument": "H100016",
                    },
                    {
                        "code": "CYLINDRES",
                        "value": "HYA++++;PAT+",
                        "instrument": "H100016",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_result_cristaux_negative(self):
    self.configure(
        atellica_cyto_ignorer_resultats_na=True,
        atellica_cyto_exclusion_resultat_cristaux="",
        atellica_cyto_exclusion_resultat_cylindres="PAT-",
    )
    date = datetime.datetime(2019, 8, 17, 16, 21, 56)
    worklist = self.decode(
        """
    H|\\^&|||Atellica UAS 800^Atellica UAS 800^4.0.200.6647^1^H100325|||||||P|LIS2-A2|20190817162531
    P|1||||BOUDJEMA Francoise
    C|1|I|Review|I
    O|1|049081713053|20^1^DS^SAMPLE|S|R||||||N|||20190817162156|||||||||||F
    R|1|798-9^^^RBC|1392.6|p/ul||A||F||DS|||Atellica UAS 800
    C|1|I|A|I
    R|2|51487-7^^^WBC|249.15|p/ul||A||F||DS|||Atellica UAS 800
    C|1|I|A|I
    R|3|53317-4^^^.WBCc|+|||A||F||DS|||Atellica UAS 800
    C|1|I|A|I
    R|4|53334-9^^^CRY|+++|||N||F||DS|||Atellica UAS 800
    R|5|33234-6^^^.CaOx|N/A|||N||F||DS|||Atellica UAS 800
    R|6|^^^.URI|N/A|||N||F||DS|||Atellica UAS 800
    R|7|53329-9^^^.ATY|N/A|||N||F||DS|||Atellica UAS 800
    R|8|50239-3^^^.U-AMO|N/A|||N||F||DS|||Atellica UAS 800
    R|9|50236-9^^^.P-AMO|N/A|||N||F||DS|||Atellica UAS 800
    R|10|50231-0^^^HYA|+|||N||F||DS|||Atellica UAS 800
    R|11|72224-9^^^PAT|-|||N||F||DS|||Atellica UAS 800
    R|12|50225-2^^^NEC|-|||N||F||DS|||Atellica UAS 800
    R|13|53318-2^^^EPI|-|||N||F||DS|||Atellica UAS 800
    R|14|72223-1^^^YEA|+|||A||F||DS|||Atellica UAS 800
    C|1|I|A|I
    R|15|50221-1^^^BAC|++|||A||F||DS|||Atellica UAS 800
    C|1|I|A|I
    R|16|^^^.BACr|++|||A||F||DS|||Atellica UAS 800
    C|1|I|A|I
    R|17|^^^.BACc|-|||N||F||DS|||Atellica UAS 800
    R|18|53321-6^^^MUC|-|||N||F||DS|||Atellica UAS 800
    R|19|33232-0^^^SPRM|-|||N||F||DS|||Atellica UAS 800
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "049081713053",
                "rack": "20-1",
                "results": [
                    {
                        "code": "RBC",
                        "date": date,
                        "flags": ["A"],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "p/ul",
                        "value": "1392.6",
                    },
                    {
                        "code": "WBC",
                        "date": date,
                        "flags": ["A"],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "p/ul",
                        "value": "249.15",
                    },
                    {
                        "code": ".WBCcQUAL",
                        "date": date,
                        "flags": ["A"],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "",
                        "value": "+",
                    },
                    {
                        "code": ".CaOxQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "",
                        "value": "N/A",
                    },
                    {
                        "code": ".URIQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "",
                        "value": "N/A",
                    },
                    {
                        "code": ".ATYQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "",
                        "value": "N/A",
                    },
                    {
                        "code": ".U-AMOQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "",
                        "value": "N/A",
                    },
                    {
                        "code": ".P-AMOQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "",
                        "value": "N/A",
                    },
                    {
                        "code": "NECQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "",
                        "value": "-",
                    },
                    {
                        "code": "EPIQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "",
                        "value": "-",
                    },
                    {
                        "code": "YEAQUAL",
                        "date": date,
                        "flags": ["A"],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "",
                        "value": "+",
                    },
                    {
                        "code": "BACQUAL",
                        "date": date,
                        "flags": ["A"],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "",
                        "value": "++",
                    },
                    {
                        "code": ".BACrQUAL",
                        "date": date,
                        "flags": ["A"],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "",
                        "value": "++",
                    },
                    {
                        "code": ".BACcQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "",
                        "value": "-",
                    },
                    {
                        "code": "MUCQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "",
                        "value": "-",
                    },
                    {
                        "code": "SPRMQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100325",
                        "operator": "DS",
                        "unit": "",
                        "value": "-",
                    },
                    {"code": "CRISTAUX", "instrument": "H100325", "value": "CRY+++"},
                    {"code": "CYLINDRES", "instrument": "H100325", "value": "HYA+"},
                ],
            }
        ],
    }
    assert worklist == expected


def test_result_control(self):
    self.configure(atellica_cyto_ignorer_resultats_na=False)
    date = datetime.datetime(2017, 10, 30, 16, 25, 52)
    worklist = self.decode(
        """
    H|\\^&|||Atellica UAS 800^Atellica UAS 800^4.0.90.5575^1^H100016|||||||Q|LIS2-A2|20171030162702
    P|1||||QC_LOW
    C|1|I|Test Passed!|G
    C|2|I|Lot ID: 2222|I
    C|3|I|Liquid Type: Quantimetrix QuanTscopics|I
    C|4|I|Expiration Date: 20180904|I
    O|1|0296|1^5^test^CONTROL|S|R||||||Q|||20171030162552|||||||||||F
    R|1|798-9^^^RBC|<4|p/ul||N||F||test|||Atellica UAS 800
    R|2|53292-9^^^RBC|In Range|||N||F||test|||Atellica UAS 800
    R|3|51487-7^^^WBC|<3|p/ul||N||F||test|||Atellica UAS 800
    R|4|53316-6^^^WBC|In Range|||N||F||test|||Atellica UAS 800
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "control_lot": "2222",
                "results": [
                    {
                        "code": "RBC",
                        "date": date,
                        "flags": [],
                        "instrument": "H100016",
                        "operator": "test",
                        "unit": "p/ul",
                        "value": "<4",
                    },
                    {
                        "code": "RBCQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100016",
                        "operator": "test",
                        "unit": "",
                        "value": "In Range",
                    },
                    {
                        "code": "WBC",
                        "date": date,
                        "flags": [],
                        "instrument": "H100016",
                        "operator": "test",
                        "unit": "p/ul",
                        "value": "<3",
                    },
                    {
                        "code": "WBCQUAL",
                        "date": date,
                        "flags": [],
                        "instrument": "H100016",
                        "operator": "test",
                        "unit": "",
                        "value": "In Range",
                    },
                ],
                "sample_id": "2222",
                "type": "control",
            }
        ],
    }
    assert worklist == expected
