# -*- coding: utf8 -*-
from __future__ import unicode_literals

import copy
import datetime

parser_class = "cobas6800"


def test_query(self):
    result = self.decode(
        """
    MSH|^~\\&|COBAS6800/8800||LIS||20161130115359||QBP^Q11|f167c187-cefc-4102-a836-fe8679e31e0b|P|2.5||||||ASCII
    QPD|WOS^Work·Order·Step^IHE_LABTF||005D783C||3001|5
    """
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "005D783C"}],
    }
    assert result == expected


def test_order(self):
    worklist = copy.deepcopy(self.order_worklist)
    worklist.samples[0].orders[0].code = "72493-0^CMV^LN^PLAS^plasma^HL70487^350"
    worklist.samples[0].orders[1].code = "72493-1^CMV^LN^PLAS^plasma^HL70487^450"
    worklist.samples[0].orders[2].code = "72493-1^CMV^LN^PLAS^plasma^HL70487^450"
    message = self.order(worklist=worklist, context={"control_id": "1524522222"})

    expected = """
    MSH|^~\\&|||COBAS6800/8800|Lab|20130715141912||OML^O33|MSG15245222220||2.5||||||ASCII|||ROC-03^ROCHE
    SPM||123456||PLAS^plasma^HL70487|||||||P
    SAC|||||||||||||||||||||350|||uL^^UCUM
    ORC|NW
    OBR|1|||72493-0^CMV^LN
    TCD|72493-0^CMV^LN|^1^:^0
    NTE|1
    MSH|^~\\&|||COBAS6800/8800|Lab|20130715141912||OML^O33|MSG15245222221||2.5||||||ASCII|||ROC-03^ROCHE
    SPM||123456||PLAS^plasma^HL70487|||||||P
    SAC|||||||||||||||||||||450|||uL^^UCUM
    ORC|NW
    OBR|1|||72493-1^CMV^LN
    TCD|72493-1^CMV^LN|^1^:^0
    NTE|1
    MSH|^~\\&|||COBAS6800/8800|Lab|20130715141912||OML^O33|MSG15245222222||2.5||||||ASCII|||ROC-03^ROCHE
    SPM||123456||PLAS^plasma^HL70487|||||||P
    SAC|||||||||||||||||||||450|||uL^^UCUM
    ORC|CA
    OBR|1|||72493-1^CMV^LN
    TCD|72493-1^CMV^LN|^1^:^0
    NTE|1
    """
    assert message == expected


def test_decode_msa(self):
    worklist = self.decode(
        """
    MSH|^~\\&|COBAS6800/8800||LIS||20210629155709||ORL^O34|289a95ab80174fb5b63b|P|2.5||||||ASCII|||ROC-03^ROCHE
    MSA|AA|MSG1624975031261
    SPM||567011801453||PLAS^plasma^HL70487|||||||P||||||
    SAC|||||||||||||||||||||200|||uL^^UCUM
    ORC|||||IP||||20210629155709
    OBR|1|||43730-1^EBV^LN|||||||
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "567011801453",
                "type": "patient",
                "specimen": "PLAS",
                "rack": "",
            }
        ],
    }
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode(
        """
    MSH|^~\\&|COBAS6800/8800||LIS||20210604181712||OUL^R22|1a169a67-9311-4dfe-92ab-75bbe99fc1bc|P|2.5||||||ASCII
    SPM||506011530281||PLAS^plasma^HL70487|||||||P||||||||||||||||
    SAC|||||||||||||||||||||350|||uL^^UCUM
    OBR|1|||72493-0^CMV^LN|||||||A
    OBX|1|NM|CMV^CMV^99ROC||915|10*-2.[iU]/mL^^UCUM|||||F|||||DataManager-200058||C6800/8800^Roche^^~Unknown^Roche^^~ID_000000000012076380^IM300-002186^^|20210604161711|||||||||44_neg^^99ROC~43_pos^^99ROC
    TCD|72493-0^CMV^LN|^1^:^0
    INV|EBV|OK|MR|||||||||20220531020000||||G29140
    INV|Tip rack|OK|SC|||||||||20230731020000||||008
    INV|Processing plate|OK|SC|||||||||20230630020000||||152
    INV|Amplification plate|OK|SC|||||||||20230531020000||||046
    INV|Diluent|OK|DI|||||||||20220930020000||||G27272
    INV|Lysis reagent|OK|LI|||||||||20221130010000||||G30726
    INV|Wash reagent|OK|LI|||||||||20221231010000||||G30659
    INV|MGP cassette|OK|SC|||||||||20220930020000||||G21066
    OBX|2|NA|CMV^CMV^99ROC^S_OTHER^Other Supplemental^IHELAW||30.59^^29.63||||||F|||||DataManager-200058||C6800/8800^Roche^^~Unknown^Roche^^~ID_000000000012076380^IM300-002186^^|20210604161711|||||||||44_neg^^99ROC~43_pos^^99ROC
    OBX|3|ST|72493-0^CMV^LN|1/1|ValueNotSet|||RR|||F|||||DataManager-200058||C6800/8800^Roche^^~Unknown^Roche^^~ID_000000000012076380^IM300-002186^^|20210604161711|||||||||44_neg^^99ROC~43_pos^^99ROC
    OBX|4|ST|72493-0^CMV^LN|1/2|Titer|||""|||F|||||DataManager-200058||C6800/8800^Roche^^~Unknown^Roche^^~ID_000000000012076380^IM300-002186^^|20210604161711|||||||||44_neg^^99ROC~43_pos^^99ROC
    TCD|72493-0^CMV^LN|^1^:^
    """
    )
    lots = [
        {
            "expiration": datetime.datetime(2022, 5, 31, 2, 0),
            "lot": "G29140",
            "type": "reagent",
        },
        {
            "expiration": datetime.datetime(2022, 11, 30, 1, 0),
            "lot": "G30726",
            "type": "reagent",
        },
        {
            "expiration": datetime.datetime(2022, 12, 31, 1, 0),
            "lot": "G30659",
            "type": "reagent",
        },
    ]

    expected = {
        "context": "result",
        "samples": [
            {
                "rack": "",
                "results": [
                    {
                        "code": "CMV_NM",
                        "value": "9.15",
                        "flags": ["F"],
                        "operator": "DataManager-200058",
                        "instrument": "C6800/8800",
                        "unit": "10*-2.[iU]/mL",
                        "date": datetime.datetime(2021, 6, 4, 16, 17, 11),
                        "comments": [],
                        "lots": lots,
                    },
                    {
                        "code": "CMV_NA",
                        "value": "30.59",
                        "flags": ["F"],
                        "operator": "DataManager-200058",
                        "instrument": "C6800/8800",
                        "unit": "",
                        "date": datetime.datetime(2021, 6, 4, 16, 17, 11),
                        "comments": [],
                        "lots": lots,
                    },
                    {
                        "code": "CMV_NAQS",
                        "value": "29.63",
                        "flags": ["F"],
                        "operator": "DataManager-200058",
                        "instrument": "C6800/8800",
                        "unit": "",
                        "date": datetime.datetime(2021, 6, 4, 16, 17, 11),
                        "comments": [],
                        "lots": lots,
                    },
                    {
                        "code": "72493-0_ST1/1",
                        "value": "ValueNotSet",
                        "flags": ["F"],
                        "operator": "DataManager-200058",
                        "instrument": "C6800/8800",
                        "unit": "",
                        "date": datetime.datetime(2021, 6, 4, 16, 17, 11),
                        "comments": [],
                        "lots": lots,
                    },
                    {
                        "code": "72493-0_STI1/1",
                        "value": "RR",
                        "flags": ["F"],
                        "operator": "DataManager-200058",
                        "instrument": "C6800/8800",
                        "unit": "",
                        "date": datetime.datetime(2021, 6, 4, 16, 17, 11),
                        "comments": [],
                        "lots": lots,
                    },
                    {
                        "code": "72493-0_ST1/2",
                        "value": "Titer",
                        "flags": ["F"],
                        "operator": "DataManager-200058",
                        "instrument": "C6800/8800",
                        "unit": "",
                        "date": datetime.datetime(2021, 6, 4, 16, 17, 11),
                        "comments": [],
                        "lots": lots,
                    },
                    {
                        "code": "72493-0_STI1/2",
                        "value": '""',
                        "flags": ["F"],
                        "operator": "DataManager-200058",
                        "instrument": "C6800/8800",
                        "unit": "",
                        "date": datetime.datetime(2021, 6, 4, 16, 17, 11),
                        "comments": [],
                        "lots": lots,
                    },
                ],
                "sample_id": "506011530281",
                "type": "patient",
                "specimen": "PLAS",
            }
        ],
    }
    assert worklist == expected
