# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "fanci"


def test_encode_order(self):
    message = self.order(context={"control_id": "1535528471269"})
    expected = """
    MSH|^~\\&||POC||FBT|20130715141912||ORM^O01|1535528471269|P|2.3|||AL
    PID|||123456||NYME ANO||20110513|F
    ORC|NW||||SC||||20130715141912
    OBR||||^^^A|20130603110342|||||||||||||||||||F
    OBR||||^^^B|20130603110342|||||||||||||||||||F
    """
    assert message == expected


def test_decode_result(self):
    date = datetime.datetime(2004, 1, 20, 16, 15, 45)
    worklist = self.decode(
        """
    MSH|^~\\&|FANBT|FAN||HCC|20060103020616||ORU^R01|090610111729|P|2.1|||AL|NE
    PID|||000004
    ORC|RE||||CM||||20060103020616
    OBR||||^^^ATC02^Aminopyrine^L||20060103020616|||||||||||||||||||F
    OBX|001|NM|^^^PDR^Percantage Dose of Recovery (PDR)^L||9,8|%/h|||||F|||20040120161545
    OBX|002|ST|^^^INTERP^Interpretation^L||normal||||||F|||20040120161545
    OBX|003|TX|^^^FINDNG^Findings^L||PDR = 9,8 %/h : normal||||||F|||20040120161545
    OBX|004|TX|^^^COMMNT^Comments^L||not fasting ?||||||F|||20040120161545
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {"code": "ATC02_PDR", "value": "9.8", "date": date},
                    {"code": "ATC02_INTERP", "value": "normal", "date": date},
                    {
                        "code": "ATC02_FINDNG",
                        "value": "PDR = 9.8 %/h : normal",
                        "date": date,
                    },
                    {"code": "ATC02_COMMNT", "value": "not fasting ?", "date": date},
                ],
                "sample_id": "000004",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_decode_result_critere(self):
    worklist = self.decode(
        """
    MSH|^~\\&|FANci V2.20.21.11|FBT||POC|20180913161304||ORU^R01|211420252417|P|2.3|||AL|NE
    PID|||000005||TEST^Essai
    ORC|RE||||CM||||20180913161304
    OBR||||^^^ATC06^UREA^L||20180913161304|20040229123422|20040229123422|||||||||||||||||F
    OBX|001|TX|^^^CRITER^Criteria^L|1|Criteres d evaluation   (Delta Over Baseline (DOB)) :||||||F|||20040116123422
    OBX|002|TX|^^^CRITER^Criteria^L|2|------------------------------------------------------||||||F|||20040116123422
    OBX|003|TX|^^^CRITER^Criteria^L|3|DOB En l espace de  30 min > 4,0   h.p. - positive||||||F|||20040116123422
    OBX|004|TX|^^^CRITER^Criteria^L|4|                            Sinon   normal||||||F|||20040116123422
    OBX|005|TX|^^^CRITER^Criteria^L|5|------------------------------------------------------||||||F|||20040116123422
    OBX|006|TX|^^^CRITER^Criteria^L|6|Ce test:                        DOB = 8,1  DOB = 8,1 ||||||F|||20040116123422
    OBX|007|TX|^^^CRITER^Criteria^L|7|------------------------------------------------------||||||F|||20040116123422
    OBX|008|TX|^^^MTABLE^Measured^L|1|Mesuré||||||F|||20040116123422
    OBX|009|TX|^^^MTABLE^Measured^L|2|Horaire/min  12CO2/%  13CO2/ppm   Delta/||||||F|||20040116123422
    OBX|010|TX|^^^MTABLE^Measured^L|3|     0     4,410     499,6     -25,2||||||F|||20040116123422
    OBX|011|TX|^^^MTABLE^Measured^L|4|    30     3,260     376,5     -17,1||||||F|||20040116123422
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "000005",
                "type": "patient",
                "results": [
                    {"code": "ATC06_MTABLE_T0_12CO2", "value": "4.410"},
                    {"code": "ATC06_MTABLE_T0_13CO2", "value": "499.6"},
                    {"code": "ATC06_MTABLE_T0_DELTA", "value": "-25.2"},
                    {"code": "ATC06_MTABLE_T30_12CO2", "value": "3.260"},
                    {"code": "ATC06_MTABLE_T30_13CO2", "value": "376.5"},
                    {"code": "ATC06_MTABLE_T30_DELTA", "value": "-17.1"},
                    {
                        "code": "ATC06_CRITER",
                        "value": "Criteres d evaluation   (Delta Over Baseline (DOB)) :\r------------------------------------------------------\rDOB En l espace de  30 min > 4,0   h.p. - positive\r                            Sinon   normal\r------------------------------------------------------\rCe test:                        DOB = 8,1  DOB = 8,1 \r------------------------------------------------------",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_result_with_status(self):
    date = datetime.datetime(2021, 9, 8, 19, 41, 7)
    worklist = self.decode(
        """
    MSH|^~\\&|FANci V2.20.40.19|FBT||POC|20210909173701||ORU^R01|241416264814|P|2.4|||AL|NE
    PID|||5002510001PQ||^
    ORC|RE||||CM||||20210909173701
    OBR||||^^^ATC06^Harnstoff^L||20210909173701|20210908193226|20210908194107|||||||||||||||||F
    OBX|001|NM|^^^DOB^Delta Over Baseline^L||1,0||||||F|||20210908194107
    OBX|002|ST|^^^INTERP^Interpretation^L||normal||||||F|||20210908194107
    OBX|003|TX|^^^FINDNG^Findings^L||DOB = 1,0  : normal||||||F|||20210908194107
    OBX|004|TX|^^^CRITER^Criteria^L|1|Critères d'évalualtion (Delta Over Baseline (DOB)) :||||||O|||20210908194107
    OBX|005|TX|^^^CRITER^Criteria^L|2|------------------------------------------------------||||||O|||20210908194107
    OBX|006|TX|^^^CRITER^Criteria^L|3|DOB En l'espace de 30 min > 4,0  h.p. - positiv||||||O|||20210908194107
    OBX|007|TX|^^^CRITER^Criteria^L|4|DOB En l'espace de 30 min > 2,5  control||||||O|||20210908194107
    OBX|008|TX|^^^CRITER^Criteria^L|5| Sinon normal||||||O|||20210908194107
    OBX|009|TX|^^^CRITER^Criteria^L|6|------------------------------------------------------||||||O|||20210908194107
    OBX|010|TX|^^^CRITER^Criteria^L|7|Ce test: DOB = 1,0  normal||||||F|||20210908194107
    OBX|011|TX|^^^CRITER^Criteria^L|8|------------------------------------------------------||||||O|||20210908194107
    OBX|012|TX|^^^MTABLE^Measured^L|1|Mesuré||||||O|||20210908194107
    OBX|013|TX|^^^MTABLE^Measured^L|2|Horaire/min 12CO2/% 13CO2/ppm Delta/ Status||||||O|||20210908194107
    OBX|014|TX|^^^MTABLE^Measured^L|3|     0     1,739     190,0     -24,3      (0)||||||F|||20210908194107
    OBX|015|TX|^^^MTABLE^Measured^L|4|    30     1,518     166,4     -23,3      (0)||||||F|||20210908194107
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {"code": "ATC06_DOB", "date": date, "value": "1.0"},
                    {"code": "ATC06_INTERP", "date": date, "value": "normal"},
                    {
                        "code": "ATC06_FINDNG",
                        "date": date,
                        "value": "DOB = 1.0  : normal",
                    },
                    {"code": "ATC06_MTABLE_T0_12CO2", "value": "1.739"},
                    {"code": "ATC06_MTABLE_T0_13CO2", "value": "190.0"},
                    {"code": "ATC06_MTABLE_T0_DELTA", "value": "-24.3"},
                    {"code": "ATC06_MTABLE_T0_STATUS", "value": "(0)"},
                    {"code": "ATC06_MTABLE_T30_12CO2", "value": "1.518"},
                    {"code": "ATC06_MTABLE_T30_13CO2", "value": "166.4"},
                    {"code": "ATC06_MTABLE_T30_DELTA", "value": "-23.3"},
                    {"code": "ATC06_MTABLE_T30_STATUS", "value": "(0)"},
                    {
                        "code": "ATC06_CRITER",
                        "value": "Critères d'évalualtion (Delta Over "
                        "Baseline (DOB)) :\r"
                        "------------------------------------------------------\r"
                        "DOB En l'espace de 30 min > 4,0  h.p. - "
                        "positiv\r"
                        "DOB En l'espace de 30 min > 2,5  control\r"
                        " Sinon normal\r"
                        "------------------------------------------------------\r"
                        "Ce test: DOB = 1,0  normal\r"
                        "------------------------------------------------------",
                    },
                ],
                "sample_id": "5002510001PQ",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected
