# -*- coding: utf8 -*-
from __future__ import unicode_literals

import copy
import datetime

parser_class = "hprim_facturation"


def test_decode_facturation(self):
    message = """H|~^\\&|||SENDER||FAC|||RECEIVER||P|H2.1~L|20170202173645
    P|1|592094|||CERRUTTI~MICHELE|HUCQ|19570615|F||29 AV DE BOULOURIS~~ST
    FAC|1|7126032017|603201|201702010823|~DIV~DERBUEL|~~
    ACT|1|B|78|1|1|17OH PROGESTERO|||1135
    L|1||1|5"""
    worklist = self.decode(message)
    assert worklist == {
        "filename": "",
        "context": "billing",
        "receiver_id": "RECEIVER",
        "samples": [
            {
                "address": "29 AV DE BOULOURIS",
                "admission_date": None,
                "admission_end_date": None,
                "admission_status": "",
                "alternate_patient_id": "",
                "bed": "",
                "billings": [
                    {
                        "catalogue": "",
                        "code_executant": "",
                        "code_nomenclature": "1135",
                        "code_rmo": "",
                        "coefficient": 78.0,
                        "denombrement": 1.0,
                        "lettre_cle": "B",
                        "libelle_acte": "17OH PROGESTERO",
                        "no_executant": "",
                        "nom_executant": "",
                        "quantite": 1.0,
                        "type_majoration": "",
                    }
                ],
                "birth_row": "",
                "birthdate": datetime.datetime(1957, 6, 15, 0, 0),
                "city": "ST",
                "collection_date": datetime.datetime(2017, 2, 1, 8, 23),
                "collection_end_date": datetime.datetime(2017, 2, 1, 8, 23),
                "country": "",
                "deathdate": None,
                "diagnostic": "",
                "exe_request_id": "603201",
                "first_name": "MICHELE",
                "height": "",
                "last_name": "CERRUTTI",
                "location": "",
                "maiden_name": "HUCQ",
                "patient_id": "592094",
                "phone": "",
                "physicians": [
                    {"code": "DIV", "last_name": "DERBUEL", "type": "prescriber"}
                ],
                "physiologie": "",
                "postal_code": "",
                "request_date": datetime.datetime(2017, 2, 1, 8, 23),
                "room": "",
                "sample_id": "7126032017",
                "sex": "F",
                "title": "",
                "type": "patient",
            }
        ],
        "sender_id": "SENDER",
    }


def test_encode_facturation(self):
    worklist = copy.deepcopy(self.result_worklist)
    worklist.context = "billing"
    worklist.samples[0].sample_id = "7126032017"
    worklist.samples[0].exe_request_id = "603201"
    worklist.samples[0].billings = [
        {
            "catalogue": "",
            "code_executant": "",
            "code_nomenclature": "1135",
            "code_rmo": "",
            "coefficient": 78,
            "denombrement": 1,
            "lettre_cle": "B",
            "libelle_acte": "17OH PROGESTERO",
            "no_executant": "",
            "nom_executant": "",
            "quantite": 1,
            "type_majoration": "",
        },
        {
            "catalogue": "",
            "code_executant": "",
            "code_nomenclature": "1135",
            "code_rmo": "",
            "coefficient": 78,
            "denombrement": 1,
            "lettre_cle": "B",
            "libelle_acte": "17OH PROGESTERO",
            "no_executant": "",
            "nom_executant": "",
            "quantite": 1,
            "type_majoration": "",
        },
    ]

    expected = """H|~^\\&|||SENDER||FAC|||RECEIVER||P|H2.1~L|20130715141912
    P|1|036666666||ADM_CLI|NYME~ANO~~~Mme|NJF|20110513|F||45 rue lambda~lala~Toulouse~~31000~FR||0123456789|ATTENDING~LAGRANGE&Joseph-Louis~L|||1.70|58||MEDOC1^MEDOC2||||20130511~20130514||42~237~LOC
    FAC|1|7126032017|603201|20130603110342|~PRESCRIBER~Prescriber|~SAMPLER~Sampler
    ACT|1|B|78|1|1|17OH PROGESTERO|||1135
    ACT|2|B|78|1|1|17OH PROGESTERO|||1135
    L|1||1|6"""

    message = self.billing(worklist=worklist)
    assert message == expected
