# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "perkinelmer"


def test_encode_order(self):
    _order = """NYME ANO;123456"""
    message = self.order()
    assert message == _order


def test_decode_result(self):
    date = datetime.datetime(2017, 7, 19, 12, 30, 53)
    worklist = self.decode(
        """
    Sample Information
    Sample ID:,190529-AQ
    Sample Type:,Sample
    Sample Date/Time:,Wednesday
    Acquisition Date/Time&Time Zone:,Wednesday
    Acquisition Date/Time-Short:,12:30:53 Wed 19-Jul-17
    Acquisition Date/Time&Zone-Short:,12:30:53 Wed 19-Jul-17 Romance Daylight Time
    Acquisition Date/Time-Intl.:,19/07/2017 12:30
    Acquisition Date/Time&Zone-Intl.:,19/07/2017 12:30:53 Romance Daylight Time
    Report Date/Time:,Friday
    Report Date/Time&Timezone:,Friday
    Report Date/Time-Short:,18:26:50 Fri 14-Jun-19
    Report Date/Time&Zone-Short:,18:26:50 Fri 14-Jun-19 Paris
    Report Date/Time-Intl.:,14/06/2019 18:26
    Report Date/Time&Zone-Intl.:,14/06/2019 18:26:50 Paris
    Summary
    Analyte,Conc. Mean,Report Unit
    Mg,13569.419483,ug/L
    Ti,1.867482,ug/L
    Co,2.770900,ug/L
    Ni,5.957608,ug/L
    Cu,39.930256,ug/L
    Zn,184.319648,ug/L
    Ga,860.284337,ug/L
    Rh-3,,ug/L
    Ir-3,325.787218,ug/L
    Ga-1,107.777939,ug/L
    Se,25.959453,ug/L
    AsO,40.127169,ug/L
    Rh-2,,ug/L
    Cd,4.698147,ug/L
    Cd,5.862050,ug/L
    Ir-2,-3467.567769,ug/L
    Hg-1,4.574849,ug/L
    Cr,2.384976,ug/L
    Mn,3.225220,ug/L
    Ga-2,-456.395658,ug/L
    Mo,9.208417,ug/L
    Rh-1,,ug/L
    Ir-1,-198.144088,ug/L
    Ga-3,-1705.947685,ug/L
    Co-1,-2.329397,ug/L
    Rh,,ug/L
    Sn,5.246082,ug/L
    Sn,-1.915584,ug/L
    Sb,9.007573,ug/L
    Sb,12.719867,ug/L
    Ir,-559.211504,ug/L
    Hg,3.404557,ug/L
    Tl,1.142554,ug/L
    Pb,17.193406,ug/L
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {
                        "code": "Mg",
                        "value": "13569.419483",
                        "unit": "ug/L",
                        "date": date,
                    },
                    {"code": "Ti", "value": "1.867482", "unit": "ug/L", "date": date},
                    {"code": "Co", "value": "2.770900", "unit": "ug/L", "date": date},
                    {"code": "Ni", "value": "5.957608", "unit": "ug/L", "date": date},
                    {"code": "Cu", "value": "39.930256", "unit": "ug/L", "date": date},
                    {"code": "Zn", "value": "184.319648", "unit": "ug/L", "date": date},
                    {"code": "Ga", "value": "860.284337", "unit": "ug/L", "date": date},
                    {
                        "code": "Ir-3",
                        "value": "325.787218",
                        "unit": "ug/L",
                        "date": date,
                    },
                    {
                        "code": "Ga-1",
                        "value": "107.777939",
                        "unit": "ug/L",
                        "date": date,
                    },
                    {"code": "Se", "value": "25.959453", "unit": "ug/L", "date": date},
                    {"code": "AsO", "value": "40.127169", "unit": "ug/L", "date": date},
                    {"code": "Cd", "value": "4.698147", "unit": "ug/L", "date": date},
                    {"code": "Cd", "value": "5.862050", "unit": "ug/L", "date": date},
                    {
                        "code": "Ir-2",
                        "value": "-3467.567769",
                        "unit": "ug/L",
                        "date": date,
                    },
                    {"code": "Hg-1", "value": "4.574849", "unit": "ug/L", "date": date},
                    {"code": "Cr", "value": "2.384976", "unit": "ug/L", "date": date},
                    {"code": "Mn", "value": "3.225220", "unit": "ug/L", "date": date},
                    {
                        "code": "Ga-2",
                        "value": "-456.395658",
                        "unit": "ug/L",
                        "date": date,
                    },
                    {"code": "Mo", "value": "9.208417", "unit": "ug/L", "date": date},
                    {
                        "code": "Ir-1",
                        "value": "-198.144088",
                        "unit": "ug/L",
                        "date": date,
                    },
                    {
                        "code": "Ga-3",
                        "value": "-1705.947685",
                        "unit": "ug/L",
                        "date": date,
                    },
                    {
                        "code": "Co-1",
                        "value": "-2.329397",
                        "unit": "ug/L",
                        "date": date,
                    },
                    {"code": "Sn", "value": "5.246082", "unit": "ug/L", "date": date},
                    {"code": "Sn", "value": "-1.915584", "unit": "ug/L", "date": date},
                    {"code": "Sb", "value": "9.007573", "unit": "ug/L", "date": date},
                    {"code": "Sb", "value": "12.719867", "unit": "ug/L", "date": date},
                    {
                        "code": "Ir",
                        "value": "-559.211504",
                        "unit": "ug/L",
                        "date": date,
                    },
                    {"code": "Hg", "value": "3.404557", "unit": "ug/L", "date": date},
                    {"code": "Tl", "value": "1.142554", "unit": "ug/L", "date": date},
                    {"code": "Pb", "value": "17.193406", "unit": "ug/L", "date": date},
                ],
                "sample_id": "190529-AQ",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    date = datetime.datetime(2020, 3, 4, 15, 57, 57)
    worklist = self.decode(
        """
    Sample Information
    Sample ID:,QC_MUR_LEV1
    Sample Type:,QC Std
    Acquisition Date/Time-Short:,15:57:57 Wed 04-Mar-20
    Report Date/Time-Short:,16:54:32 Wed 04-Mar-20
    Summary
    Analyte,Conc. Mean,Report Unit
    Be,0.164802,ug/L
    Al,11.494578,ug/L
    V,18.424158,ug/L
    Cr,5.753976,ug/L
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {"code": "Be", "date": date, "unit": "ug/L", "value": "0.164802"},
                    {"code": "Al", "date": date, "unit": "ug/L", "value": "11.494578"},
                    {"code": "V", "date": date, "unit": "ug/L", "value": "18.424158"},
                    {"code": "Cr", "date": date, "unit": "ug/L", "value": "5.753976"},
                ],
                "sample_id": "QC_MUR_LEV1",
                "control_lot": "QC_MUR_LEV1",
                "specimen": "MUR",
                "type": "control",
            }
        ],
    }
    assert worklist == expected
