# -*- coding: utf8 -*-
from __future__ import unicode_literals

parser_class = "starrsed"


def test_encode_order(self):
    message = self.order()
    expected = "ESRSR                       123456                                                                                         Y "
    assert message == expected


def test_decode_query(self):
    message = "ESRSR   1234                12345678                                                                                       R "
    worklist = self.decode(message)
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "12345678"}],
    }
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode(
        "ESRRE   1234                12345678                                               16022016  1210 111  222  333  444            0    0                                  1                                                                                    "
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "12345678",
                "results": [
                    {"code": "ESR30", "value": "111", "flags": ["1"]},
                    {"code": "ESR60", "value": "333", "flags": ["1"]},
                    {"code": "ESR120", "value": "444", "flags": ["1"]},
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_other_result(self):
    worklist = self.decode(
        "ESRRE                       120170918065                                           18092017  1712                                   0             63   30   20  112    0    3                                                                                Q"
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "120170918065",
                "results": [
                    {"code": "ESR30", "value": "", "flags": ["3"]},
                    {"code": "ESR60", "value": "", "flags": ["3"]},
                    {"code": "ESR120", "value": "", "flags": ["3"]},
                ],
            }
        ],
    }
    assert worklist == expected
