# -*- coding: utf8 -*-
from __future__ import unicode_literals

import copy
import datetime

parser_class = "walkaway"


def test_encode_order(self):
    worklist = copy.deepcopy(self.order_worklist)
    worklist.samples[0]["results"][0]["resu_json"]["germes"][0]["Plaques"] = "NM39"
    message = self.order(worklist=worklist)
    expected = """
    P,1,036666666,NYME,ANO,20110513,F,,,,,ATTENDING,LAGRANGE,,,LOC,LOCATION,,,,,,,,,,,
    B,,123456,036666666,,,A,,,20130513,114242,,,,,,,,,,,,,,
    R,1,1,123456,NM39,,,,N,,,1,,,,,,,,,,,,,,,,,,,,,,,,,,,,
    B,,123456,036666666,,,B,,,20130513,114242,,,,,,,,,,,,,,
    R,1,1,123456,NM39,,,,N,,,1,,,,,,,,,,,,,,,,,,,,,,,,,,,,
    """
    assert message == expected


def test_decode_result(self):
    date = datetime.datetime(2017, 1, 20, 0, 0)
    worklist = self.decode(
        """
    H,ValiScan,,LabPro,0.2,",",,N,,,,Y,,,
    P,1,107211,TEST,BERNADETTE,19450808,F,,,,,DEFMI1,DE FILIPPI MIREILLE,,,,,O,O,N,N,,,0,,
    B,1,650701181053,107211,,,CBU,CBU,N,20170118,000000,,,,,,F,0,N,,,,,,
    R,1,1,650701181053,NM39,Neg MIC 39,20170120,,N,,,1,Escherichia coli,,,,,,,,,,,,,N,,,Neg,,31,,N,,1,1,,1,F,,
    C,1,*LOT NM39,,2017-10-03,,R,Y,
    M,1,AK,Amikacine,<=4,N,,S,S,,,,,,,,,,,,,,,,,N
    M,2,AMX,Amoxicilline,>8,N,,R,R,,,,,,,,,,,,,,,,,N
    M,3,AUG,Amox/Ac.Clav,>8,N,,R,R,,,,,,,,,,,,,,,,,N
    M,4,AZT,Aztrenam,<=1,N,,S,S,,,,,,,,,,,,,,,,,N
    M,5,CAZ,Ceftazidime,4,N,,N/A,N/A,,,,,,,,,,,,,,,,,N
    M,6,CPT,Ceftaroline,<=0.5,N,,,,,,,,,,,,,,,,,,,,N
    P,1,107212,TEST2,BERNADETTE,19450808,F,,,,,DEFMI1,DE FILIPPI MIREILLE,,,,,O,O,N,N,,,0,,
    B,1,650701181054,107211,,,CBU,CBU,N,20170118,000000,,,,,,F,0,N,,,,,,
    R,1,1,650701181053,NM39,Neg MIC 39,20170120,,N,,,1,Escherichia coli,,,,,,,,,,,,N,,,Neg,,31,,N,,1,1,,1,F,,
    C,1,*LOT NM39,,2017-10-03,,R,Y,
    M,1,AK,Amikacine,<=4,N,,S,S,,,,,,,,,,,,,,,,,N
    R,2,2,650701181053,NM39,Neg MIC 39,20170120,,N,,,2,toto coli,,,,,,,,,,,,N,,,Neg,,31,,N,,1,1,,1,F,,
    M,1,AMX,Amoxicilline,>8,N,,R,R,,,,,,,,,,,,,,,,,N
    L,L,Y,,
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {
                        "code": "CBU",
                        "date": date,
                        "nom_antibiogramme": "NM39",
                        "value": [
                            {
                                "antibiogram": [
                                    {
                                        "antibiotic": "A_AK",
                                        "mic": "<=4",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_AMX",
                                        "mic": ">8",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_AUG",
                                        "mic": ">8",
                                        "sensitivity": "R",
                                    },
                                    {
                                        "antibiotic": "A_AZT",
                                        "mic": "<=1",
                                        "sensitivity": "S",
                                    },
                                ],
                                "sub_code": "1",
                                "value": "G_1",
                            }
                        ],
                    },
                    {
                        "code": "IDENT_CBU",
                        "date": date,
                        "nom_antibiogramme": "NM39",
                        "value": {
                            "germes": [{"rang": 1, "id": "G_1", "Id": "G_1"}],
                            "seq": "1",
                            "type_resultat": "identification_germes",
                        },
                    },
                    {"code": "IDENT_1_CBU", "value": "G_1"},
                ],
                "sample_id": "650701181053",
                "type": "patient",
            },
            {
                "results": [
                    {
                        "code": "CBU",
                        "date": date,
                        "nom_antibiogramme": "NM39",
                        "value": [
                            {
                                "antibiogram": [
                                    {
                                        "antibiotic": "A_AK",
                                        "mic": "<=4",
                                        "sensitivity": "S",
                                    }
                                ],
                                "sub_code": "1",
                                "value": "G_1",
                            }
                        ],
                    },
                    {
                        "code": "IDENT_CBU",
                        "date": date,
                        "nom_antibiogramme": "NM39",
                        "value": {
                            "germes": [{"rang": 1, "id": "G_1", "Id": "G_1"}],
                            "seq": "1",
                            "type_resultat": "identification_germes",
                        },
                    },
                    {"code": "IDENT_1_CBU", "value": "G_1"},
                    {
                        "code": "CBU",
                        "date": date,
                        "nom_antibiogramme": "NM39",
                        "value": [
                            {
                                "antibiogram": [
                                    {
                                        "antibiotic": "A_AMX",
                                        "mic": ">8",
                                        "sensitivity": "R",
                                    }
                                ],
                                "sub_code": "2",
                                "value": "G_2",
                            }
                        ],
                    },
                    {
                        "code": "IDENT_CBU",
                        "date": date,
                        "nom_antibiogramme": "NM39",
                        "value": {
                            "germes": [{"rang": 2, "id": "G_2", "Id": "G_2"}],
                            "seq": "2",
                            "type_resultat": "identification_germes",
                        },
                    },
                    {"code": "IDENT_2_CBU", "value": "G_2"},
                ],
                "sample_id": "650701181054",
                "type": "patient",
            },
        ],
    }
    assert worklist == expected
